@@ -201,6 +201,7 @@ expand(const char *cp,	/* input word */
 	make_magic = 0;
 	word = (f&DOBLANK) ? IFS_WS : IFS_WORD;
 	st_head.next = NULL;
+	st_head.quote = 0;
 	st = &st_head;
 
 	while (1) {
@@ -1106,7 +1107,7 @@ debunk(char *dp, const char *sp, size_t dlen)
 	if ((s = ((const char *)strchr(sp, MAGIC)))) {
 		if (s - sp >= (ssize_t)dlen)
 			return dp;
-		memcpy(dp, sp, s - sp);
+		memmove(dp, sp, s - sp);
 		for (d = dp + (s - sp); *s && (d - dp < (ssize_t)dlen); s++)
 			if (!ISMAGIC(*s) || !(*++s & 0x80) ||
 			    !strchr("*+?@! ", *s & 0x7f))
